using GalaSoft.MvvmLight;
using WorkCountdown7.Model;
using System.Collections.ObjectModel;
using System.Windows.Input;
using GalaSoft.MvvmLight.Command;
using System;

namespace WorkCountdown7.ViewModel
{
    /// <summary>
    /// This class contains properties that the main View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm
    /// </para>
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        private ObservableCollection<TimerItem> items = new ObservableCollection<TimerItem>();

        public ObservableCollection<TimerItem> Items { get { return this.items; } }

        public MainViewModel()
        {
            this.Execute = new RelayCommand(ExecuteAction);
        }

        public ICommand Execute { get; private set; }

        private void ExecuteAction()
        {
            if (this.currentItem == null)
            {
                // no value
                this.currentItem = new TimerItem { StartTime = DateTime.Now };
                this.items.Add(this.currentItem);
            }
            else if (!this.currentItem.StopTime.HasValue)
            {
                this.currentItem.StopTime = DateTime.Now;
            }
            else
            {
                this.currentItem = new TimerItem { StartTime = DateTime.Now };
                this.items.Add(this.currentItem);
            }
        }

        private TimerItem currentItem;
    }
}